require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xaddomain',
  dscmeta_resource_friendly_name: 'xADDomain',
  dscmeta_resource_name: 'MSFT_xADDomain',
  dscmeta_module_name: 'xActiveDirectory',
  dscmeta_module_version: '2.13.0.0',
  docs: 'The DSC xADDomain resource type.
         Automatically generated from version 2.13.0.0',
  features: ['simple_get_filter', 'canonicalize'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_sysvolpath: {
      type: 'Optional[String]',
      desc: 'Path to a directory where the Sysvol file will be written',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_dnsdelegationcredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Credential used for creating DNS delegation',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_domainadministratorcredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Credentials used to query for domain existence',
      behaviour: :parameter,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_logpath: {
      type: 'Optional[String]',
      desc: 'Path to a directory for the log file that will be written',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_databasepath: {
      type: 'Optional[String]',
      desc: 'Path to a directory that contains the domain database',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_domainnetbiosname: {
      type: 'Optional[String]',
      desc: 'NetBIOS name for the new domain',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_domainname: {
      type: 'String',
      desc: 'Name of the domain to which the user will be added',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_safemodeadministratorpassword: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Password for the administrator account when the computer is started in Safe Mode',
      behaviour: :parameter,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_parentdomainname: {
      type: 'Optional[String]',
      desc: 'Fully qualified name of the parent domain',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
