require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xaddomaintrust',
  dscmeta_resource_friendly_name: 'xADDomainTrust',
  dscmeta_resource_name: 'MSFT_xADDomainTrust',
  dscmeta_module_name: 'xActiveDirectory',
  dscmeta_module_version: '2.13.0.0',
  docs: 'The DSC xADDomainTrust resource type.
         Automatically generated from version 2.13.0.0',
  features: ['simple_get_filter', 'canonicalize'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_targetdomainadministratorcredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Credentials to authenticate to the target domain',
      behaviour: :parameter,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_trustdirection: {
      type: "Enum['Bidirectional', 'Inbound', 'Outbound']",
      desc: 'Direction of trust',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: 'Should this resource be present or absent',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_trusttype: {
      type: "Enum['External', 'Forest']",
      desc: 'Type of trust',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sourcedomainname: {
      type: 'String',
      desc: 'Name of the AD domain that is requesting the trust',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_targetdomainname: {
      type: 'String',
      desc: 'Name of the AD domain that is being trusted',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
