require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xaduser',
  dscmeta_resource_friendly_name: 'xADUser',
  dscmeta_resource_name: 'MSFT_xADUser',
  dscmeta_module_name: 'xActiveDirectory',
  dscmeta_module_version: '2.13.0.0',
  docs: 'The DSC xADUser resource type.
         Automatically generated from version 2.13.0.0',
  features: ['simple_get_filter', 'canonicalize'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_company: {
      type: 'Optional[String]',
      desc: "Specifies the user's company (ldapDisplayName 'company')",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_homepage: {
      type: 'Optional[String]',
      desc: "Specifies the URL of the home page of the object (ldapDisplayName 'wWWHomePage')",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ipphone: {
      type: 'Optional[String]',
      desc: "Specifies the user's IP telephony phone number (ldapDisplayName 'ipPhone')",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_description: {
      type: 'Optional[String]',
      desc: "Specifies a description of the object (ldapDisplayName 'description')",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_distinguishedname: {
      type: 'Optional[String]',
      desc: 'Returns the X.500 path of the object',
      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_office: {
      type: 'Optional[String]',
      desc: "Specifies the location of the user's office or place of business (ldapDisplayName 'physicalDeliveryOfficeName')",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_displayname: {
      type: 'Optional[String]',
      desc: "Specifies the display name of the object (ldapDisplayName 'displayName')",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_enabled: {
      type: 'Optional[Boolean]',
      desc: 'Specifies if the account is enabled (default True)',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_password: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Specifies a new password value for the account',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_domaincontroller: {
      type: 'Optional[String]',
      desc: 'Specifies the Active Directory Domain Services instance to use to perform the task.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_pager: {
      type: 'Optional[String]',
      desc: "Specifies the user's pager number (ldapDisplayName 'pager')",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_path: {
      type: 'Optional[String]',
      desc: 'Specifies the X.500 path of the Organizational Unit (OU) or container where the new object is created',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_emailaddress: {
      type: 'Optional[String]',
      desc: "Specifies the user's e-mail address (ldapDisplayName 'mail')",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_fax: {
      type: 'Optional[String]',
      desc: "Specifies the user's fax phone number (ldapDisplayName 'facsimileTelephoneNumber')",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_homedirectory: {
      type: 'Optional[String]',
      desc: "Specifies a user's home directory path (ldapDisplayName 'homeDirectory')",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_country: {
      type: 'Optional[String]',
      desc: "Specifies the country or region code for the user's language of choice (ldapDisplayName 'c')",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_logonscript: {
      type: 'Optional[String]',
      desc: "Specifies a path to the user's log on script (ldapDisplayName 'scriptPath')",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_userprincipalname: {
      type: 'Optional[String]',
      desc: "Specifies the UPN assigned to the user account (ldapDisplayName 'userPrincipalName')",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_domainadministratorcredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Specifies the user account credentials to use to perform this task',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_state: {
      type: 'Optional[String]',
      desc: "Specifies the user's or Organizational Unit's state or province (ldapDisplayName 'st')",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_city: {
      type: 'Optional[String]',
      desc: "Specifies the user's town or city (ldapDisplayName 'l')",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_cannotchangepassword: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether the account password can be changed',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_commonname: {
      type: 'Optional[String]',
      desc: "Specifies the common nane assigned to the user account (ldapDisplayName 'cn')",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_mobilephone: {
      type: 'Optional[String]',
      desc: "Specifies the user's mobile phone number (ldapDisplayName 'mobile')",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_passwordauthentication: {
      type: "Optional[Enum['Default', 'Negotiate']]",
      desc: 'Specifies the authentication context type used when testing passwords',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_employeenumber: {
      type: 'Optional[String]',
      desc: "Specifies the user's employee number (ldapDisplayName 'employeeNumber')",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_passwordneverexpires: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether the password of an account can expire',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_initials: {
      type: 'Optional[String]',
      desc: "Specifies the initials that represent part of a user's name (ldapDisplayName 'initials')",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: 'Specifies whether the user account is created or deleted',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_division: {
      type: 'Optional[String]',
      desc: "Specifies the user's division (ldapDisplayName 'division')",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_jobtitle: {
      type: 'Optional[String]',
      desc: "Specifies the user's title (ldapDisplayName 'title')",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_givenname: {
      type: 'Optional[String]',
      desc: "Specifies the user's given name (ldapDisplayName 'givenName')",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_employeeid: {
      type: 'Optional[String]',
      desc: "Specifies the user's employee ID (ldapDisplayName 'employeeID')",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_officephone: {
      type: 'Optional[String]',
      desc: "Specifies the user's office telephone number (ldapDisplayName 'telephoneNumber')",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_manager: {
      type: 'Optional[String]',
      desc: "Specifies the user's manager specified as a Distinguished Name (ldapDisplayName 'manager')",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_homephone: {
      type: 'Optional[String]',
      desc: "Specifies the user's home telephone number (ldapDisplayName 'homePhone')",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_streetaddress: {
      type: 'Optional[String]',
      desc: "Specifies the user's street address (ldapDisplayName 'streetAddress')",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_username: {
      type: 'String',
      desc: "Specifies the Security Account Manager (SAM) account name of the user (ldapDisplayName 'sAMAccountName')",
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_profilepath: {
      type: 'Optional[String]',
      desc: "Specifies a path to the user's profile (ldapDisplayName 'profilePath')",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_department: {
      type: 'Optional[String]',
      desc: "Specifies the user's department (ldapDisplayName 'department')",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_homedrive: {
      type: 'Optional[String]',
      desc: "Specifies a drive that is associated with the UNC path defined by the HomeDirectory property (ldapDisplayName 'homeDrive')",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_surname: {
      type: 'Optional[String]',
      desc: "Specifies the user's last name or surname (ldapDisplayName 'sn')",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_notes: {
      type: 'Optional[String]',
      desc: "Specifies the notes attached to the user's accoutn (ldapDisplayName 'info')",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_domainname: {
      type: 'String',
      desc: 'Name of the domain where the user account is located (only used if password is managed)',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_pobox: {
      type: 'Optional[String]',
      desc: "Specifies the user's post office box number (ldapDisplayName 'postOfficeBox')",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_postalcode: {
      type: 'Optional[String]',
      desc: "Specifies the user's postal code or zip code (ldapDisplayName 'postalCode')",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
